package net.udby.datetime;

import java.util.Calendar;
import java.util.Date;

/**
 * Interface defining methods for obtaining "current time"
 */
public interface DateTimeProvider {
	/**
	 * Returns current time as Calendar
	 * 
	 * @see Calendar#getInstance()
	 * @return
	 */
	Calendar currentTimeCalendar();
	/**
	 * Returns current time in milliseconds
	 * 
	 * @see System#currentTimeMillis()
	 * @return
	 */
	long currentTimeMilliseconds();
	/**
	 * Returns current time as Date
	 * 
	 * @see Date
	 * @return
	 */
	Date currentTimeDate();

	/**
	 * Default DateTime provider using standard jdk methods
	 */
	DateTimeProvider DEFAULT = new DateTimeProvider() {
		@Override
		public Calendar currentTimeCalendar() {
			return Calendar.getInstance();
		}

		@Override
		public long currentTimeMilliseconds() {
			return System.currentTimeMillis();
		}

		@Override
		public Date currentTimeDate() {
			return new Date();
		}
	};
}
