package net.udby.datetime.jpa;

import java.io.Serializable;
import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.persistence.Version;

@Entity(name=Item.ENTITY_NAME)
@Table(name=Item.TABLE_NAME)
@NamedQueries({
	@NamedQuery(name=Item.QRY_FIND_ACTIVE, query="SELECT i FROM " + Item.ENTITY_NAME + " i WHERE (i.effective IS NULL OR :now >= i.effective) AND (i.expiry IS NULL OR :now < i.expiry)")
})
public class Item implements Serializable {
	private static final long serialVersionUID = 1L;

	public static final String TABLE_NAME = "ITEM";
	public static final String ENTITY_NAME = "Item";
	
	public static final String QRY_FIND_ACTIVE = ENTITY_NAME + ".findActive";
	
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Column(name="ID", updatable = false, unique = true, nullable = false)
	private int id;
	
	@Column(name="ITEM_TEXT", length=50, nullable=false)
	private String itemText;
	
	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="EFFECTIVE", nullable=true)
	private Date effective;
	
	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="EXPIRY", nullable=true)
	private Date expiry;

	@Temporal(TemporalType.TIMESTAMP)
	@Column(name="CREATED", updatable=false, nullable=true)
	private Calendar created;
	
	@Column(name="UPDATED", nullable=true)
	@Version
	private Timestamp updated;

	public Item() {
	}

	public String getItemText() {
		return itemText;
	}

	public void setItemText(String itemText) {
		this.itemText = itemText;
	}

	public Date getEffective() {
		return effective;
	}

	public void setEffective(Date effective) {
		this.effective = effective;
	}

	public Date getExpiry() {
		return expiry;
	}

	public void setExpiry(Date expiry) {
		this.expiry = expiry;
	}

	public Calendar getCreated() {
		return created;
	}

	public void setCreated(Calendar created) {
		this.created = created;
	}

	public int getId() {
		return id;
	}

	public Timestamp getUpdated() {
		return updated;
	}

}
