package net.udby.datetime.ejb;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import javax.persistence.EntityManager;

public class EMProxyHandler implements InvocationHandler {
	private final EntityManager em;
	private final Object ejb;
	
	public EMProxyHandler(final EntityManager em, final Object ejb) {
		this.em = em;
		this.ejb = ejb;
	}

	@Override
	public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
		em.clear();
		em.getTransaction().begin();
		try {
			Object ret = method.invoke(ejb, args);
			em.flush();
			em.getTransaction().commit();
			return ret;
		} catch (Exception e) {
			if (em.getTransaction().isActive()) {
				em.getTransaction().rollback();
			}
			if (e instanceof InvocationTargetException) {
				throw e.getCause(); 
			}
			throw e;
		}
	}
}
